@@ -278,6 +278,7 @@ public:
 		EXIT_THREAD,		// thread death notify
 		EXIT_TIMER,		// timer notified exit
 		NULL_EVENT,		// generic null event pusher
+		ERROR_STATE,		// generic enter with error
 
 		// primary session control events
 
@@ -317,6 +318,7 @@ public:
 		REPLAY_LIBEXEC,
 		RESTART_LIBEXEC,
 		TONE_LIBEXEC,
+		XFER_LIBEXEC,
 
 		// primary driver events
 
