@@ -116,6 +116,56 @@ void BayonneTSession::sysInput(const char *tsid, char *tok)
 	leave();
 }
 
+void BayonneTSession::sysXfer(const char *tsid, const char *id)
+{
+	Event event;
+	const char *pre;
+	const char *svr;
+
+	memset(&event, 0, sizeof(event));
+	event.id = XFER_LIBEXEC;
+	event.libexec.tid = tsid;
+	enter();
+
+	if(isLibexec(tsid))
+	{
+		switch(iface)
+		{
+		case IF_INET:
+			pre = driver->getLast("urlprefix");
+			if(!pre)
+				pre = "";
+			svr = driver->getLast("outbound");
+			if(strchr(id, '@'))
+				svr = NULL;
+			state.url.ref = id;
+			if(svr)
+			{
+				snprintf(state.url.buf, sizeof(state.url.buf), "%s%s@%s", pre, svr, id);
+				state.url.ref = state.url.buf;
+			}
+			break;
+		case IF_PSTN:
+			pre = driver->getLast("prefix");
+			if(!pre)
+				pre = "!";
+
+			state.tone.exiting = true;
+			if(audio.tone)
+				delete audio.tone;
+			snprintf(state.tone.digits, sizeof(state.tone.digits), "%s%s", pre, id);
+			audio.tone = new DTMFTones(state.tone.digits, 20000, getToneFraming());
+			event.id = TONE_LIBEXEC;
+			break;
+		default:
+			state.result = RESULT_INVALID;
+			event.id = RESTART_LIBEXEC;
+		}
+		postEvent(&event);
+	}
+	leave();
+}
+
 void BayonneTSession::sysReplay(const char *tsid, char *tok)
 {
 	Event event;
