@@ -205,11 +205,13 @@ bool Session::enterXfer(Event *event)
 {
 	if(event->id == ENTER_STATE)
 	{
-		if(eXosip_transfer_call(did, (char *)state.url.ref))
+		if(!eXosip_transfer_call(did, (char *)state.url.ref))
 		{
 			setState(STATE_HANGUP);
 			return true;
 		}
+		event->errmsg = "transfer-invalid";
+		event->id = ERROR_STATE;
 	}
 	return false;
 }
