@@ -50,7 +50,10 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	if(env)
 		loadFile(env, "voicetronix");
 #else
-	load("~bayonne/voicetronix");
+	if(Bayonne::provision_system)
+		load("/bayonne/provision/voicetronix");
+	else if(Bayonne::provision_user)
+		load("~bayonne/voicetronix");
 #endif
 	cp = getLast("pickup");
 	if(cp)
