@@ -175,7 +175,7 @@ const char *Checks::chkTransfer(Line *line, ScriptImage *img)
 	if(getMember(line))
 		return "transfer has no members";
 
-	if(!useKeywords(line, "=prefix"))
+	if(!useKeywords(line, "=prefix=server"))
 		return "invalid keyword used";
 
 	if(!getOption(line, &idx))
