@@ -390,6 +390,7 @@ void testConfig(char *argv0)
 	keypaths.setValue("logfiles", SOURCE_FILES "/server/tempfiles");
 	keypaths.setValue("runfiles", SOURCE_FILES "/server/tempfiles");
 #endif
+	runtime.setValue("virtual.tts", "theta");
 	keypaths.setValue("modexec", "../scripts");
 	Dir::create("tempfiles");
 	keyserver.setValue("state", "test");
@@ -407,6 +408,7 @@ void loadConfig(void)
 	keypaths.loadFile(pbuf, "paths");
 	keyserver.loadFile(pbuf, "server");
 	keyengine.loadFile(pbuf, "engine");
+	runtime.loadFile(pbuf, "virtual", "virtual");
 
 	snprintf(pbuf, sizeof(pbuf), "%s/driver.conf", config);
 	Process::setEnv("DRIVERCONFIG", pbuf, true); 
@@ -433,11 +435,13 @@ void loadConfig(void)
 	else
 		strcpy(homepath, "tempfiles");
 
+	runtime.loadPrefix("virtual", "/bayonne/server/virtual");
 	if(Bayonne::provision_user)
 	{
 		keypaths.load("~bayonne/paths");
 		keyserver.load("~bayonne/server");
 		keyengine.load("~bayonne/engine");
+		runtime.loadPrefix("virtual", "~bayonne/virtual");
 	}
 
 	if(Bayonne::provision_system)
@@ -445,6 +449,7 @@ void loadConfig(void)
 		keypaths.load("/bayonne/provision/paths");
 		keyserver.load("/bayonne/provision/server");
 		keyengine.load("/bayonne/provision/engine");
+		runtime.loadPrefix("virtual", "/bayonne/provision/virtual");
 	}
 
 	umask(007);
@@ -510,6 +515,7 @@ bool parseConfig(char **argv)
 	unsigned scrcount = 0;
 	unsigned timeslots = atoi(keyengine.getLast("timeslots"));
 	unsigned minslots = 0;
+	bool live = true;
 
 	if(**argv != '-')
 		driver=*(argv++);
@@ -534,7 +540,7 @@ retry:
 		++argv;
 		goto retry;
 	} 
-
+	
 	if(!strnicmp(option, "-logging=", 9))
         {
                 keyserver.setValue("logging", option + 9);
@@ -543,6 +549,13 @@ retry:
         }
 
 
+	if(!strnicmp(option, "-macros=", 8))
+	{
+		runtime.setValue("include", option + 8);
+		++argv;
+		goto retry;
+	} 
+
         if(!strnicmp(option, "-libexec=", 9))
         {
                 keypaths.setValue("libexec", option + 9);
@@ -551,6 +564,13 @@ retry:
         }
             
 
+	if(!stricmp(option, "-check"))
+	{
+		live = false;
+		++argv;
+		goto retry;
+	}
+
 	if(!strnicmp(option, "-vvv", 4))
 	{
 		keyserver.setValue("logging", "debug");
@@ -632,6 +652,18 @@ retry:
                 goto retry;
         }
 
+        if(!stricmp(option, "-macros"))     
+        {
+                ++argv;
+                if(!*argv)
+                {
+                        cerr << "bayonne: " << cmd << ": -macros: missing argument" << endl;
+                        exit(-1);
+                }
+                runtime.setValue("include", *(argv++));
+                goto retry;
+        } 
+
 	if(!stricmp(option, "-logging"))
         {
                 ++argv;
@@ -721,61 +753,64 @@ retry:
 	}
 
 skip:
-	if(!driver)
+	if(!driver && live)
 	{
 		cerr << "bayonne: driver missing" << endl;
 		exit(-1);
 	}
 
+	if(live)
+	{
 #ifdef	WIN32
-	Process::setEnv("DISPLAY", "yes", true);
-	if(!stricmp(driver, "console"))
-	{
-		Process::setEnv("DISPLAY", "", true);
-		driver = "soundcard";
-	}
+		Process::setEnv("DISPLAY", "yes", true);
+		if(!stricmp(driver, "console"))
+		{
+			Process::setEnv("DISPLAY", "", true);
+			driver = "soundcard";
+		}
 #else
-	if(!stricmp(driver, "console"))
-	{
-		Process::setEnv("DISPLAY", "", true);
-		driver = "soundcard";
-	}
+		if(!stricmp(driver, "console"))
+		{
+			Process::setEnv("DISPLAY", "", true);
+			driver = "soundcard";
+		}
 #endif
 
-	ext = strchr(driver, ':');
-	if(ext)
-	{
-		*(ext++) = 0;
-		minslots += atoi(ext);
-		snprintf(buffer, sizeof(buffer), "slots.%s", driver);
-		runtime.setValue(buffer, ext);
-	}
+		ext = strchr(driver, ':');
+		if(ext)
+		{
+			*(ext++) = 0;
+			minslots += atoi(ext);
+			snprintf(buffer, sizeof(buffer), "slots.%s", driver);
+			runtime.setValue(buffer, ext);
+		}
 
-	if(timeslots < minslots)
-		timeslots = minslots;
+		if(timeslots < minslots)
+			timeslots = minslots;
 
-	snprintf(buffer, sizeof(buffer), "%s.stack", driver);
-	keyoptions.setValue(buffer, "0");
+		snprintf(buffer, sizeof(buffer), "%s.stack", driver);
+		keyoptions.setValue(buffer, "0");
 		
-	keyserver.setValue("driver", driver);
-	snprintf(path, 10, "%d", timeslots);
-	keyserver.setValue("timeslots", path);
+		keyserver.setValue("driver", driver);
+		snprintf(path, 10, "%d", timeslots);
+		keyserver.setValue("timeslots", path);
  
-	prefix = keypaths.getLast("drivers");
+		prefix = keypaths.getLast("drivers");
 #ifdef	WIN32
-	snprintf(path, sizeof(path), "%s/%s" RLL_SUFFIX, prefix, driver);
+		snprintf(path, sizeof(path), "%s/%s" RLL_SUFFIX, prefix, driver);
 #else
-	if(!strnicmp(prefix, "..", 2))
-		snprintf(path, sizeof(path), "%s/%s/.libs/%s.ivr", prefix, driver, driver);
-	else
-		snprintf(path, sizeof(path), "%s/%s.ivr", prefix, driver);
+		if(!strnicmp(prefix, "..", 2))
+			snprintf(path, sizeof(path), "%s/%s/.libs/%s.ivr", prefix, driver, driver);
+		else
+			snprintf(path, sizeof(path), "%s/%s.ivr", prefix, driver);
 #endif
-	keyoptions.setValue("driver", path);
+		keyoptions.setValue("driver", path);
 
-	if(!canAccess(path))
-	{
-		cerr << "server exiting; " << path << " missing" << endl;
-		exit(-1);
+		if(!canAccess(path))
+		{
+			cerr << "server exiting; " << path << " missing" << endl;
+			exit(-1);
+		}
 	}
 	
 	while(*argv)
