@@ -126,6 +126,10 @@ bool Methods::scrTransfer(void)
 	unsigned len = 0;
 	const char *cp;
 	const char *pre = getKeyword("prefix");
+	const char *svr = getKeyword("server");
+
+	if(!svr)
+		svr = driver->getLast("outbound");
 
 	if(!pre)
 		pre = driver->getLast("transfer");
@@ -139,10 +143,23 @@ bool Methods::scrTransfer(void)
 	switch(iface)
 	{
 	case IF_INET:
-		if(pre)
-			snprintf(state.url.buf, sizeof(state.url.buf), "%s@%s", pre, nbuf);
+		pre = driver->getLast("urlprefix");
+		if(!pre)
+			pre = "";
+
+		if(strchr(nbuf, '@'))
+			svr = NULL;
+
+		if(svr)
+			snprintf(state.url.buf, sizeof(state.url.buf), "%s%s@%s", pre, nbuf, svr);
 		else
 			snprintf(state.url.buf, sizeof(state.url.buf), "%s", nbuf);
+
+		if(*pre && strnicmp(state.url.buf, pre, strlen(pre)))
+		{
+			error("invalid-url");
+			return true;
+		}
 		state.url.ref = state.url.buf;
 		setState(STATE_XFER);
 		return false;
@@ -1499,14 +1516,6 @@ bool Methods::scrReadpath(void)
 	const char *cp;
 	Symbol *sym;
 
-	if(cp)
-	{
-                slog.error("%s: %s", logname, cp);
-                if(!signalScript(SIGNAL_FAIL))
-                        error("invalid-audio");
-		return true;
-	}
-
 	cp = getOption(NULL);
 	if(!cp)
 		goto nosym;
