@@ -75,6 +75,12 @@ ScriptRuntime()
 			(Check)&Checks::chkDir},
 		{"pathname", false, (Method)&Methods::scrPathname,
 			(Check)&Checks::chkPathname},
+		{"readpath", true, (Method)&Methods::scrReadpath,
+			(Check)&Checks::chkPaths},
+		{"writepath", true, (Method)&Methods::scrWritepath,
+			(Check)&Checks::chkPaths},
+		{"path", true, (Method)&Methods::scrPath,
+			(Check)&Checks::chkPaths},
 		{"voicelib", false, (Method)&Methods::scrVoicelib,
 			(Check)&Checks::chkVoicelib},
 		{"timeslot", true, (Method)&Methods::scrTimeslot,
@@ -340,18 +346,38 @@ bool Runtime::testDriver(ScriptInterp *interp, const char *v)
 
 bool Runtime::testFile(ScriptInterp *interp, const char *v)
 {
-	char buf[128];
+	BayonneSession *s = (BayonneSession *)(interp);
+	char buf[MAX_PATHNAME];
+	char *ext;
+
+	if(!v || !*v)
+		return false;
+
+	// lets accept any valid path, including those from read/writepath
+	if(*v == '/' || v[1] == ':')
+		goto cont;
+
+	ext = strrchr(v, '/');
+	if(ext)
+		ext = strrchr(ext, '.');
+	else
+		ext = strrchr(v, '.');
+
+	if(ext)
+		ext = "";
+	else
+		ext = ".au";
 
 	if(!strnicmp(buf, "tmp:", 4))
 	{
-		snprintf(buf, sizeof(buf), "%s/%s", path_tmp, v + 4);
+		snprintf(buf, sizeof(buf), "%s/%s%s", path_tmp, v + 4, ext);
 		v = buf;
 		goto cont;
 	}
 
         if(!strnicmp(buf, "ram:", 4) || !strnicmp(buf, "mem:", 4))
         {
-                snprintf(buf, sizeof(buf), "%s/%s", path_tmpfs, v + 4);
+                snprintf(buf, sizeof(buf), "%s/%s%s", path_tmpfs, v + 4, ext);
                 v = buf;
                 goto cont;
         }
@@ -362,6 +388,15 @@ bool Runtime::testFile(ScriptInterp *interp, const char *v)
 	if(strchr(v, ':'))
 		return false;
 
+	if(strchr(v, '/'))
+		snprintf(buf, sizeof(buf), "%s/%s%s", 
+			keypaths.getLast("datafiles"), v, ext);
+	else
+		snprintf(buf, sizeof(buf), "%s/%s/%s%s",
+			path_prompts, s->defVoicelib(), v, ext);
+
+	v = buf;
+
 cont:
 	if(strstr(v, ".."))
 		return false;
@@ -374,7 +409,13 @@ cont:
 
 bool Runtime::testDir(ScriptInterp *interp, const char *v)
 {
-	char buf[128];
+	char buf[MAX_PATHNAME];
+
+	if(!v || !*v)
+		return false;
+
+	if(*v == '/' || v[1] == ':')
+		goto cont;
 
 	if(!strnicmp(buf, "tmp:", 4))
 	{
@@ -396,6 +437,9 @@ bool Runtime::testDir(ScriptInterp *interp, const char *v)
 	if(strchr(v, ':'))
 		return false;
 
+	snprintf(buf, sizeof(buf), "%s/%s", keypaths.getLast("datafiles"), v);
+	v = buf;
+
 cont:
 	if(strstr(v, ".."))
 		return false;
