@@ -102,7 +102,7 @@ static void loadStack(const char *id)
 	d->start();
 }	
 
-static void loading(void)
+static void loading(bool live)
 {
 	char buffer[256];
 	char lang[32];
@@ -114,6 +114,13 @@ static void loading(void)
 	BayonneDriver *driver;
 	BayonneTranslator *translator = NULL;
 	static char vlib[64];
+#ifdef	HAVE_LIBEXEC
+	size_t bs = 0;
+	int pri = 0;
+#endif
+
+	if(!live)
+		goto reload;
 
 	if(!Process::getEnv("SERVER_SYSEXEC"))
 		Process::setEnv("SERVER_SYSEXEC", keypaths.getLast("scripts"), true);
@@ -123,17 +130,14 @@ static void loading(void)
 		Process::setEnv("SHELL_BTSEXEC", cp, true);
 
 	Process::setEnv("SERVER_PREFIX", keypaths.getLast("datafiles"), true);
-        Process::setEnv("SERVER_PROMPTS", keypaths.getLast("prompts"), true);
-        Process::setEnv("SERVER_SCRIPTS", keypaths.getLast("scripts"), true);
-        Process::setEnv("SERVER_LIBEXEC", keypaths.getLast("libexec"), true);     
-        Process::setEnv("SERVER_SOFTWARE", "bayonne", true);
-        Process::setEnv("SERVER_VERSION", VERSION, true);
-        Process::setEnv("SERVER_TOKEN", " ", true);
+       	Process::setEnv("SERVER_PROMPTS", keypaths.getLast("prompts"), true);
+       	Process::setEnv("SERVER_SCRIPTS", keypaths.getLast("scripts"), true);
+       	Process::setEnv("SERVER_LIBEXEC", keypaths.getLast("libexec"), true);     
+       	Process::setEnv("SERVER_SOFTWARE", "bayonne", true);
+       	Process::setEnv("SERVER_VERSION", VERSION, true);
+       	Process::setEnv("SERVER_TOKEN", " ", true);
 
 #ifdef	HAVE_LIBEXEC
-	size_t bs = 0;
-	int pri = 0;
-
 	cp = keyengine.getLast("gateways");
 	if(cp)
 		pri = atoi(cp);
@@ -145,9 +149,8 @@ static void loading(void)
 	getcwd(buffer, sizeof(buffer));
 
 	BayonneSysexec::allocate(keypaths.getLast("libexec"), bs, pri,
-		keypaths.getLast("modexec"));
+	keypaths.getLast("modexec"));
 #endif
-
 	PersistProperty::load();
 
         cp = keyserver.getLast("language");
@@ -230,7 +233,7 @@ start:
 #ifdef	HAVE_LIBEXEC
 	BayonneSysexec::startup();
 #endif
-
+reload:
 	Bayonne::reload();
 	if(!Bayonne::compile_count)
 	{
@@ -239,6 +242,8 @@ start:
 	}
 	else
 		Bayonne::errlog("notice", "%d applications compiled", Bayonne::compile_count); 
+	if(!live)
+		exit(0);
 	BayonneService::start();
 	Bayonne::errlog("notice", "%s driver started; %d timeslot(s) used", dname, count);
 #ifndef	WIN32
@@ -265,6 +270,16 @@ static void logging(void)
 		slog.level(Slog::levelDebug);
 }
 
+static void checking(char **argv)
+{
+	loadConfig();
+	keyserver.setValue("logging", "debug");
+	parseConfig(--argv);
+	logging();
+	loading(false);
+	stop(0);
+}
+
 static void starting(char **argv, bool trace)
 {
 	loadConfig();
@@ -296,7 +311,7 @@ static void starting(char **argv, bool trace)
                 keyserver.getLast("cpu"), keyserver.getLast("platform"),
 		keyserver.getLast("driver"), keyserver.getLast("timeslots"));
 
-	loading();
+	loading(true);
 	Runtime::process();
 }
 
@@ -374,7 +389,7 @@ static void testing(char **argv)
 		keyserver.getLast("cpu"), keyserver.getLast("platform"),
 		keyserver.getLast("driver"), keyserver.getLast("timeslots"));
 
-	loading();
+	loading(true);
 	Runtime::process();
 }
 
@@ -433,6 +448,8 @@ int main(int argc, char **argv)
 		testing(argv);
 	else if(!stricmp(cp, "-trace") || !stricmp(cp, "-load"))
 		starting(argv, true);
+	else if(!stricmp(cp, "-check"))
+		checking(argv);
 	else if(!stricmp(cp, "-start"))
 	{
 #ifdef	WIN32
